@@ -28,10 +28,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <libintl.h>
-#include <tracker.h>
-#include <tracker-client.h>
 #include <glib/gi18n-lib.h>
 #include <gio/gio.h>
+#include <dbus/dbus.h>
+#include <tracker.h>
 
 #include "totem-tracker-widget.h"
 #include "totem-cell-renderer-video.h"
@@ -44,7 +44,7 @@
 #define TRACKER_INTERFACE		"org.freedesktop.Tracker.Search"
 #define TOTEM_TRACKER_MAX_RESULTS_SIZE	20
 
-G_DEFINE_TYPE (TotemTrackerWidget, totem_tracker_widget, GTK_TYPE_EVENT_BOX)
+G_DEFINE_TYPE (TotemTrackerWidget, totem_tracker_widget, GTK_TYPE_VBOX)
 
 struct TotemTrackerWidgetPrivate {
 	GtkWidget *search_entry;
@@ -74,8 +74,6 @@ enum {
 	PROP_TOTEM
 };
 
-static void totem_tracker_widget_class_init	(TotemTrackerWidgetClass *klass);
-static void totem_tracker_widget_init		(TotemTrackerWidget	 *widget);
 static void totem_tracker_widget_dispose	(GObject *object);
 static void totem_tracker_widget_set_property	(GObject *object,
 						 guint property_id,
@@ -187,7 +185,7 @@ get_search_count (TrackerClient *client, const char *search)
 			   G_TYPE_INVALID, G_TYPE_INT, &count, G_TYPE_INVALID);
 
 	if (error) {
-		g_warning (error->message);
+		g_warning ("%s", error->message);
 		g_error_free (error);
 		return -1;
 	}
@@ -385,7 +383,8 @@ totem_tracker_widget_init (TotemTrackerWidget *widget)
 
 	init_result_list (widget);
 
-	v_box = gtk_vbox_new (FALSE, 2);
+	v_box = gtk_vbox_new (FALSE, 6);
+	gtk_container_set_border_width (GTK_CONTAINER (v_box), 5);
 
 	/* Search entry */
 	widget->priv->search_entry = gtk_entry_new ();
@@ -395,10 +394,10 @@ totem_tracker_widget_init (TotemTrackerWidget *widget)
 
 	/* Add the search entry and button to the search box,
 	   and add the search box to the main vertical box */
-	search_box = gtk_hbox_new (FALSE, 2);	
-	gtk_container_add (GTK_CONTAINER (search_box), widget->priv->search_entry);
-	gtk_container_add (GTK_CONTAINER (search_box), widget->priv->search_button);	
-	gtk_box_pack_start (GTK_BOX (v_box), search_box, FALSE, FALSE, 2);
+	search_box = gtk_hbox_new (FALSE, 2);
+	gtk_box_pack_start (GTK_BOX (search_box), widget->priv->search_entry, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (search_box), widget->priv->search_button, FALSE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (v_box), search_box, FALSE, TRUE, 0);
 
 	/* Insert the result list and initialize the viewport */
 	scroll = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (NULL, NULL));
