@@ -51,14 +51,14 @@ static void totem_playlist_clear_with_compare (TotemPlaylist *playlist,
 					       gconstpointer data);
 
 /* Callback function for GtkBuilder */
-void totem_playlist_save_files (GtkWidget *widget, TotemPlaylist *playlist);
-void totem_playlist_add_files (GtkWidget *widget, TotemPlaylist *playlist);
-void playlist_remove_button_clicked (GtkWidget *button, TotemPlaylist *playlist);
-void totem_playlist_up_files (GtkWidget *widget, TotemPlaylist *playlist);
-void totem_playlist_down_files (GtkWidget *widget, TotemPlaylist *playlist);
-void playlist_copy_location_action_callback (GtkAction *action, TotemPlaylist *playlist);
-void playlist_select_subtitle_action_callback (GtkAction *action, TotemPlaylist *playlist);
-void playlist_remove_action_callback (GtkAction *action, TotemPlaylist *playlist);
+G_MODULE_EXPORT void totem_playlist_save_files (GtkWidget *widget, TotemPlaylist *playlist);
+G_MODULE_EXPORT void totem_playlist_add_files (GtkWidget *widget, TotemPlaylist *playlist);
+G_MODULE_EXPORT void playlist_remove_button_clicked (GtkWidget *button, TotemPlaylist *playlist);
+G_MODULE_EXPORT void totem_playlist_up_files (GtkWidget *widget, TotemPlaylist *playlist);
+G_MODULE_EXPORT void totem_playlist_down_files (GtkWidget *widget, TotemPlaylist *playlist);
+G_MODULE_EXPORT void playlist_copy_location_action_callback (GtkAction *action, TotemPlaylist *playlist);
+G_MODULE_EXPORT void playlist_select_subtitle_action_callback (GtkAction *action, TotemPlaylist *playlist);
+G_MODULE_EXPORT void playlist_remove_action_callback (GtkAction *action, TotemPlaylist *playlist);
 
 
 typedef struct {
@@ -1611,10 +1611,10 @@ totem_playlist_init (TotemPlaylist *playlist)
 	/* popup menu */
 	playlist->priv->action_group = GTK_ACTION_GROUP (gtk_builder_get_object (playlist->priv->xml, "playlist-action-group"));
 	playlist->priv->ui_manager = GTK_UI_MANAGER (gtk_builder_get_object (playlist->priv->xml, "totem-playlist-ui-manager"));
-
+	
 	gtk_widget_add_events (GTK_WIDGET (playlist), GDK_KEY_PRESS_MASK);
 	g_signal_connect (G_OBJECT (playlist), "key_press_event",
-			G_CALLBACK (totem_playlist_key_press), playlist);
+			  G_CALLBACK (totem_playlist_key_press), playlist);
 
 	/* Reparent the vbox */
 	container = GTK_WIDGET (gtk_builder_get_object (playlist->priv->xml, "vbox4"));
@@ -1632,6 +1632,10 @@ totem_playlist_init (TotemPlaylist *playlist)
 	playlist->priv->model = gtk_tree_view_get_model
 		(GTK_TREE_VIEW (playlist->priv->treeview));
 
+	/* tooltips */
+	gtk_tree_view_set_tooltip_column(GTK_TREE_VIEW(playlist->priv->treeview),
+					 FILENAME_COL);
+
 	/* The configuration */
 	init_config (playlist);
 
