@@ -63,7 +63,7 @@ boolean_to_string (gboolean data)
 }
 
 static void
-totem_print_string (BaconVideoWidget *bvw, const char *key, BaconVideoWidgetMetadataType id)
+totem_print_string (BaconVideoWidget *bvw, const char *key, BvwMetadataType id)
 {
 	GValue value = { 0, };
 	const char *str;
@@ -78,7 +78,7 @@ totem_print_string (BaconVideoWidget *bvw, const char *key, BaconVideoWidgetMeta
 }
 
 static void
-totem_print_int (BaconVideoWidget *bvw, const char *key, BaconVideoWidgetMetadataType id)
+totem_print_int (BaconVideoWidget *bvw, const char *key, BvwMetadataType id)
 {
 	GValue value = { 0, };
 	int num;
@@ -204,7 +204,7 @@ int main (int argc, char **argv)
 	path = filenames[0];
 	if (time_limit != FALSE)
 		totem_resources_monitor_start (path, 0);
-	if (bacon_video_widget_open (bvw, path, &error) == FALSE) {
+	if (bacon_video_widget_open (bvw, path, NULL, &error) == FALSE) {
 		g_print ("Can't open %s: %s\n", path, error->message);
 		return 1;
 	}
